[Bps-public-commit] GnuPG-Interface branch master updated. 1.03-5-gfdcc3f4

BPS Git Server git at git.bestpractical.com
Tue Dec 12 22:30:34 UTC 2023


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GnuPG-Interface".

The branch, master has been updated
       via  fdcc3f408e2d50687a00d46a9e4a9419429677c7 (commit)
       via  c247048c844f872c0b2039b5d413425660b12c60 (commit)
       via  379fd37236a47a1cc45a9e4e13c5f0ee41a18aae (commit)
       via  14bc0b96539f41fb723f9f03084664db524f528b (commit)
       via  c47bec42d6769bdd3d94cf3d41d4ff948452b977 (commit)
      from  bf069cec55bf1dcbbc62f191c22b539951a80879 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit fdcc3f408e2d50687a00d46a9e4a9419429677c7
Author: sunnavy <sunnavy at bestpractical.com>
Date:   Tue Dec 12 17:23:55 2023 -0500

    Prep version 1.04

diff --git a/Changes b/Changes
index 4b751a2..4213acb 100644
--- a/Changes
+++ b/Changes
@@ -1,5 +1,9 @@
 Revision history for GnuPG-Interface
 
+1.04 - 2023-12-12
+ - Use the included fake gpg for better test portability
+ - Update tests for gpg 2.4
+
 1.03 - 2023-09-14
  - Add fix for running in taint mode for Perl 5.38.0(thanks to Andrew Ruthven)
 
diff --git a/MANIFEST b/MANIFEST
index 9b4ea89..ae08b26 100644
--- a/MANIFEST
+++ b/MANIFEST
@@ -77,6 +77,7 @@ test/public-keys/2.1.test
 test/public_keys.pgp
 test/secret-keys/1.0.test
 test/secret-keys/1.1.test
+test/secret-keys/1.2.2.test
 test/secret-keys/1.2.test
 test/secret-keys/2.0.test
 test/secret_keys.pgp
diff --git a/META.yml b/META.yml
index 97ed694..ab8ded2 100644
--- a/META.yml
+++ b/META.yml
@@ -28,4 +28,4 @@ requires:
   Scalar::Util: 0
 resources:
   license: http://dev.perl.org/licenses/
-version: '1.03'
+version: '1.04'
diff --git a/lib/GnuPG/Interface.pm b/lib/GnuPG/Interface.pm
index cf7b04c..353745e 100644
--- a/lib/GnuPG/Interface.pm
+++ b/lib/GnuPG/Interface.pm
@@ -29,7 +29,7 @@ use GnuPG::Options;
 use GnuPG::Handles;
 use Scalar::Util 'tainted';
 
-$VERSION = '1.03';
+$VERSION = '1.04';
 
 has passphrase => (
     isa     => 'Any',

commit c247048c844f872c0b2039b5d413425660b12c60
Author: sunnavy <sunnavy at bestpractical.com>
Date:   Tue Dec 12 17:21:30 2023 -0500

    Update doc declaring that 2.4 is also supported

diff --git a/README b/README
index 2ef6dd4..55de163 100644
--- a/README
+++ b/README
@@ -68,16 +68,16 @@ DESCRIPTION
     Another Process" in perlipc.
 
 GnuPG Versions
-    As of this version of GnuPG::Interface, there are two supported versions
-    of GnuPG: 1.4.x and 2.2.x. The GnuPG download page
+    As of this version of GnuPG::Interface, there are three supported
+    versions of GnuPG: 1.4.x, 2.2.x, and 2.4.x. The GnuPG download page
     <https://gnupg.org/download/index.html> has updated information on the
     currently supported versions.
 
     GnuPG released 2.0 and 2.1 versions in the past and some packaging
     systems may still provide these if you install the default "gpg",
-    "gnupg", "gnupg2", etc. packages. This modules supports only version
-    2.2.x, so you may need to find additional package repositories or build
-    from source to get the updated version.
+    "gnupg", "gnupg2", etc. packages. 2.0 and 2.1 versions are not
+    supported, so you may need to find additional package repositories or
+    build from source to get the updated version.
 
 OBJECT METHODS
   Initialization Methods
diff --git a/lib/GnuPG/Interface.pm b/lib/GnuPG/Interface.pm
index 1778c7d..cf7b04c 100644
--- a/lib/GnuPG/Interface.pm
+++ b/lib/GnuPG/Interface.pm
@@ -46,7 +46,7 @@ has call => (
 
 # NB: GnuPG versions
 #
 # There are now two supported versions of GnuPG: legacy 1.4 and stable 2.2
 # They are detected and each behave slightly differently.
 #
 # When using features specific to branches, check that the system's
@@ -988,16 +988,16 @@ L<perlipc/"Bidirectional Communication with Another Process">.
 
 =head1 GnuPG Versions
 
-As of this version of GnuPG::Interface, there are two supported
-versions of GnuPG: 1.4.x and 2.2.x. The
+As of this version of GnuPG::Interface, there are three supported
+versions of GnuPG: 1.4.x, 2.2.x, and 2.4.x. The
 L<GnuPG download page|https://gnupg.org/download/index.html> has
 updated information on the currently supported versions.
 
 GnuPG released 2.0 and 2.1 versions in the past and some packaging
 systems may still provide these if you install the default C<gpg>,
-C<gnupg>, C<gnupg2>, etc. packages. This modules supports only
-version 2.2.x, so you may need to find additional package
-repositories or build from source to get the updated version.
+C<gnupg>, C<gnupg2>, etc. packages. 2.0 and 2.1 versions are not
+supported, so you may need to find additional package repositories
+or build from source to get the updated version.
 
 =head1 OBJECT METHODS
 

commit 379fd37236a47a1cc45a9e4e13c5f0ee41a18aae
Merge: bf069ce 14bc0b9
Author: sunnavy <sunnavy at bestpractical.com>
Date:   Tue Dec 12 16:37:53 2023 -0500

    Merge branch 'update-tests-for-gpg-2.4'


-----------------------------------------------------------------------

Summary of changes:
 Changes                                   |  4 ++++
@@ -46,7 +46,7 @@ has call => (
 # NB: GnuPG versions
 #
-# There are now two supported versions of GnuPG: legacy 1.4 and stable 2.2
+# There are now three supported versions of GnuPG: legacy 1.4, 2.2, and 2.4.
 # They are detected and each behave slightly differently.
 #
 MANIFEST                                  |  1 +
 META.yml                                  |  2 +-
 README                                    | 10 +++++-----
 lib/GnuPG/Interface.pm                    | 14 +++++++-------
 t/get_public_keys.t                       |  2 +-
 t/get_secret_keys.t                       |  2 +-
 t/list_secret_keys.t                      | 19 +++++++++++--------
 t/taint_mode.t                            |  2 +-
 test/secret-keys/{1.2.test => 1.2.2.test} |  0
 test/secret-keys/1.2.test                 |  2 +-
 11 files changed, 33 insertions(+), 25 deletions(-)
 copy test/secret-keys/{1.2.test => 1.2.2.test} (100%)


hooks/post-receive
-- 
GnuPG-Interface


More information about the Bps-public-commit mailing list